@@ -121,16 +121,16 @@ def nav_column(self, view, boxes, context):
             box.render(w=html.append, view=view)
         if html:
             # only display aside columns if html availble
-            self.w(u'<div id="aside-main-%s" class="col-md-3">\n' %
+            self.w(u'<aside id="aside-main-%s" class="col-md-3 cwjs-aside">\n' %
                    context)
             self.w(u'\n'.join(html))
-            self.w(u'</div>\n')
+            self.w(u'</aside>\n')
     return len(boxes)
 
 @monkeypatch(basetemplates.TheMainTemplate)
 def content_column(self, view, content_cols):
     w = self.w
-    w(u'<div id="pageContent" class="col-md-%(col)s" role="main" data-col="%(col)s">' % {
+    w(u'<div id="pageContent" class="col-md-%(col)s" role="main">' % {
         'col': content_cols})
     components = self._cw.vreg['components']
     self.content_components(view, components)
